summaryrefslogtreecommitdiffstats
path: root/src/Mobs/PassiveMonster.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Mobs/PassiveMonster.h')
-rw-r--r--src/Mobs/PassiveMonster.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/Mobs/PassiveMonster.h b/src/Mobs/PassiveMonster.h
index 7f20c3092..a7e574a1d 100644
--- a/src/Mobs/PassiveMonster.h
+++ b/src/Mobs/PassiveMonster.h
@@ -20,9 +20,8 @@ public:
/** When hit by someone, run away */
virtual bool DoTakeDamage(TakeDamageInfo & a_TDI) override;
- /** Returns the item that the animal of this class follows when a player holds it in hand
- Return an empty item not to follow (default). */
- virtual const cItem GetFollowedItem(void) const { return cItem(); }
+ /** Returns the items that the animal of this class follows when a player holds it in hand. */
+ virtual void GetFollowedItems(cItems & a_Items) { }
} ;